@@ -29,7 +29,7 @@
 #include <eel/eel-lib-self-check-functions.h>
 #include <eel/eel-self-checks.h>
 #include <gdk/gdkrgb.h>
-#include <gtk/gtkmain.h>
+#include <gtk/gtk.h>
 #include <libgnomeui/gnome-ui-init.h>
 #include <libxml/parser.h>
 #include <stdlib.h>
