@@ -47,8 +47,8 @@
 #define EEL_LABELED_IMAGE_H
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gtk/gtkcontainer.h>
-#include <libart_lgpl/art_rect.h>
+#include <gtk/gtk.h>
+#include <eel/eel-art-extensions.h>
 
 G_BEGIN_DECLS
 
@@ -74,6 +74,8 @@ struct EelLabeledImage
 struct EelLabeledImageClass
 {
 	GtkContainerClass parent_class;
+
+	void (*activate) (EelLabeledImage *image);
 };
 
 /* Public GtkLabeledImage methods */
@@ -91,6 +93,8 @@ gboolean        eel_labeled_image_get_show_label                   (const EelLab
 void            eel_labeled_image_set_show_image                   (EelLabeledImage         *labeled_image,
 								    gboolean                 show_image);
 gboolean        eel_labeled_image_get_show_image                   (const EelLabeledImage   *labeled_image);
+void            eel_labeled_image_set_can_focus                    (EelLabeledImage         *labeled_image,
+								    gboolean                 can_focus);
 void            eel_labeled_image_set_spacing                      (EelLabeledImage         *labeled_image,
 								    guint                    spacing);
 guint           eel_labeled_image_get_spacing                      (const EelLabeledImage   *labeled_image);
@@ -111,7 +115,10 @@ void            eel_labeled_image_set_fill                         (EelLabeledIm
 gboolean        eel_labeled_image_get_fill                         (const EelLabeledImage   *labeled_image);
 void            eel_labeled_image_set_fixed_image_height           (EelLabeledImage         *labeled_image,
 								    int                      fixed_image_height);
-									 
+void            eel_labeled_image_set_selected                     (EelLabeledImage         *labeled_image,
+								    gboolean                 selected);
+gboolean        eel_labeled_image_get_selected                     (EelLabeledImage         *labeled_image);
+
 /* Functions for creating stock GtkButtons with a labeled image child */
 GtkWidget *     eel_labeled_image_button_new                       (const char              *text,
 								    GdkPixbuf               *pixbuf);
@@ -125,6 +132,10 @@ GtkWidget *     eel_labeled_image_check_button_new                 (const char
 								    GdkPixbuf               *pixbuf);
 GtkWidget *     eel_labeled_image_check_button_new_from_file_name  (const char              *text,
 								    const char              *pixbuf_file_name);
+GtkWidget *     eel_labeled_image_radio_button_new                 (const char              *text,
+								    GdkPixbuf               *pixbuf);
+GtkWidget *     eel_labeled_image_radio_button_new_from_file_name  (const char              *text,
+								    const char              *pixbuf_file_name);
 
 /* These are proxies for methods in EelImage and EelLabel */
 void            eel_labeled_image_set_pixbuf                       (EelLabeledImage         *labeled_image,
@@ -135,8 +146,8 @@ GdkPixbuf*      eel_labeled_image_get_pixbuf                       (const EelLab
 void            eel_labeled_image_set_text                         (EelLabeledImage         *labeled_image,
 								    const char              *text);
 char*           eel_labeled_image_get_text                         (const EelLabeledImage   *labeled_image);
-ArtIRect        eel_labeled_image_get_image_bounds                 (const EelLabeledImage   *labeled_image);
-ArtIRect        eel_labeled_image_get_label_bounds                 (const EelLabeledImage   *labeled_image);
+EelIRect        eel_labeled_image_get_image_bounds                 (const EelLabeledImage   *labeled_image);
+EelIRect        eel_labeled_image_get_label_bounds                 (const EelLabeledImage   *labeled_image);
 
 G_END_DECLS
 
